@@ -11,8 +11,8 @@ __version__ = _version.get_versions()["version"]
 from xopt.log import configure_logger
 
 
-def output_notebook():
+def output_notebook(**kwargs):
     """
     Redirects logging to stdout for use in Jupyter notebooks
     """
-    configure_logger()
+    configure_logger(**kwargs)
