@@ -11,6 +11,7 @@ from xopt.generators.bayesian.objectives import (
 
 from xopt.vocs import VOCS
 from ...errors import XoptError
+from ...utils import format_option_descriptions
 from .bayesian_generator import BayesianGenerator
 from .options import AcqOptions, BayesianOptions
 
@@ -27,10 +28,15 @@ class MOBOOptions(BayesianOptions):
 
 class MOBOGenerator(BayesianGenerator):
     alias = "mobo"
+    __doc__ = (
+        """Implements Multi-Objective Bayesian Optimization using the Expected
+            Hypervolume Improvement acquisition function"""
+        + f"{format_option_descriptions(MOBOOptions())}"
+    )
 
     def __init__(self, vocs: VOCS, options: MOBOOptions = None):
         options = options or MOBOOptions()
-        if not isinstance(options, MOBOOptions):
+        if not type(options) is MOBOOptions:
             raise ValueError("options must be a MOBOOptions object")
 
         super().__init__(vocs, options)
@@ -75,11 +81,12 @@ class MOBOGenerator(BayesianGenerator):
         acq = qNoisyExpectedHypervolumeImprovement(
             model,
             X_baseline=inputs,
-            prune_baseline=True,
             constraints=constraint_callables,
             ref_point=self.reference_point,
             sampler=self.sampler,
             objective=self.objective,
+            cache_root=False,
+            prune_baseline=True,
         )
 
         return acq
