@@ -23,20 +23,14 @@ def TNK(individual):
     x2 = individual[1]
     objectives = (x1, x2)
     constraints = (
-        x1 ** 2 + x2 ** 2 - 1.0 - 0.1 * np.cos(16 * np.arctan2(x1, x2)),
+        x1**2 + x2**2 - 1.0 - 0.1 * np.cos(16 * np.arctan2(x1, x2)),
         (x1 - 0.5) ** 2 + (x2 - 0.5) ** 2,
     )
     return objectives, constraints
 
 
 # labeled version
-def evaluate_TNK(
-    inputs: Dict,
-    sleep=0,
-    random_sleep=0,
-    raise_probability=0,
-    **params
-):
+def evaluate_TNK(inputs: Dict, sleep=0, random_sleep=0, raise_probability=0, **params):
     ind = [inputs["x1"], inputs["x2"]]
     objectives, constraints = TNK(ind)
 
